# Приложение для взаимодействия с Tick-Tick посредством REST API

Разработка проекта ведется на **python 3.8** с использованием библиотеки **requests**, для тестирования используется библиотека **pytest 6.2.2**

------

<b>Планируется реализовать:</b>

- [ ] Авторизация в приложении
- [ ] Получение проектов, задач
- [ ] Создание задач, проектов, тегов

##### Запуск

*Перед запуском тестов убедитесь, что установили все зависимости*

```
pip install -r requirements.txt
pytest --cov=src tests/tests.py
```

